@@ -16,8 +16,7 @@ def function_cache(name='default', keys=None, key_prefix=None, **kwargs):
         sig = signature(decorated_func)
         pass_cache_key = '_cache_key' in sig.parameters or any(param.kind == param.VAR_KEYWORD for param in sig.parameters.values())
 
-        if _key_prefix is None:
-            cache_key_prefix = f'{decorated_func.__module__}.{decorated_func.__name__}'
+        cache_key_prefix = f'{decorated_func.__module__}.{decorated_func.__name__}' if _key_prefix is None else _key_prefix
 
         @wraps(decorated_func)
         def wrapper(*args, **kwargs):
